@@ -39,6 +39,32 @@ class Names:
         return self.name
 
 
+class ControlAttach:
+    def __init__(self, type: AttachType, event: str, **kwargs: dict[str, Any]) -> None:
+        self.type = type
+        self.event = event
+        self.extra = kwargs
+
+    @classmethod
+    def from_dict(cls, data: dict[str, Any]) -> "ControlAttach":
+        data = dict(data)
+        attach_type = AttachType(data.pop("_type"))
+        event = data.pop("event")
+        return cls(
+            type=attach_type,
+            event=event,
+            **data,
+        )
+
+    @override
+    def __repr__(self) -> str:
+        return f"ControlAttach(type={self.type!r}, event={self.event!r}, extra={self.extra!r})"
+
+    @override
+    def __str__(self) -> str:
+        return f"ControlAttach: {self.event}"
+
+
 class PhotoAttach:
     def __init__(
         self,
@@ -181,7 +207,7 @@ class FileRequest:
         return cls(
             unsafe=data["unsafe"],
             url=data["url"],
-    )
+        )
 
 
 class VideoRequest:
@@ -197,15 +223,16 @@ class VideoRequest:
 
     @classmethod
     def from_dict(cls, data: dict[str, Any]) -> "VideoRequest":
-
-        listdata = list(data.values()) # Костыль ✅
-
+        # listdata = list(data.values()) # Костыль ✅
+        url = [v for k, v in data.items() if k not in ("EXTERNAL", "cache")][
+            0
+        ]  # Еще больший костыль ✅
         return cls(
             external=data["EXTERNAL"],
             cache=data["cache"],
-            url=listdata[2],
-    )
-        
+            url=url,
+        )
+
 
 class Me:
     def __init__(
@@ -280,7 +307,7 @@ class Message:
         text: str,
         status: MessageStatus | str | None,
         type: MessageType | str,
-        attaches: list[PhotoAttach | VideoAttach | FileAttach],
+        attaches: list[PhotoAttach | VideoAttach | FileAttach | ControlAttach] | None,
     ) -> None:
         self.chat_id = chat_id
         self.sender = sender
@@ -305,6 +332,8 @@ class Message:
                 attaches.append(VideoAttach.from_dict(a))
             elif a["_type"] == AttachType.FILE:
                 attaches.append(FileAttach.from_dict(a))
+            elif a["_type"] == AttachType.CONTROL:
+                attaches.append(ControlAttach.from_dict(a))
         return cls(
             chat_id=data.get("chatId"),
             sender=message.get("sender"),
